#!/bin/bash
#
# Copyright (c) 2023 VMware Carbon Black, all rights reserved
#

function curl_exec() {
  curl -v --connect-timeout 10 -u "$ES_USER:$ES_PASSWORD" "$ES_PROTOCOL://$ES_HOST:$ES_PORT/config/_doc/${1}?pretty=true" -XPOST -H 'Content-Type: application/json' -d "${2}"
}

function populate_elasticsearch() {
  TIME=$(date +%s%3N)
  echo -e "\n$(date) POPULATING ELASTICSEARCH"
  curl_exec "GLOBAL_RANSOMWARE_CONFIG" '{
    "paramKey" : "GLOBAL_RANSOMWARE_CONFIG",
    "paramValue" : "{\"canaryPayloadTimestampMap\":{\"MAC\":1673285264999,\"WINDOWS\":1673285264999},\"canaryPayloadPathMap\":{\"MAC\":\"s3://path/to/mac/payload\",\"WINDOWS\":\"s3://path/to/win/payload/new\"}}",
    "paramType" : "GLOBAL_RANSOMWARE_CONFIG",
    "description" : null,
    "createTime" : 1673285264745,
    "lastUpdateTime" : 1673285264999,
    "updateVersion" : 2
  }'

  curl_exec "GLOBAL_CERT" '{
    "paramKey" : "GLOBAL_CERT",
    "paramValue" : "{\"canaryPayloadTimestampMap\":{\"MAC\":1673285268647,\"WINDOWS\":1673285268647},\"canaryPayloadPathMap\":{\"MAC\":\"s3://path/to/mac/payload\",\"WINDOWS\":\"s3://path/to/win/payload/new\"}}",
    "paramType" : "GLOBAL_CERT",
    "description" : null,
    "createTime" : 1673285264745,
    "lastUpdateTime" : 1673285264999,
    "updateVersion" : 2
  }'

  curl_exec "GLOBAL_POLICY" '{
    "paramKey" : "GLOBAL_POLICY",
    "paramValue" : "{\"canaryPayloadTimestampMap\":{\"MAC\":1673285268647,\"WINDOWS\":1673285268647},\"canaryPayloadPathMap\":{\"MAC\":\"s3://path/to/mac/payload\",\"WINDOWS\":\"s3://path/to/win/payload/new\"}}",
    "paramType" : "GLOBAL_POLICY",
    "description" : null,
    "createTime" : 1673285264745,
    "lastUpdateTime" : 1673285264999,
    "updateVersion" : 2
  }'
  echo "$(date) DONE POPULATING ELASTICSEARCH"
}

function populate_postgres_via_file() {
  echo "${@}" >>/tmp/insert.sql
}

# Here is an example curl request that works with this data.
# curl -v -X POST http://localhost:5005/hinting/v1/hints -d '{"org_key":"7ZP4H2LG", "device_group_id":14148669, "device_id":6424575, "version":1, "last_update_time":1674147375359, "last_live_query_time":1674147375359, "remote_rules_required":true}' -H  "Content-Type: application/json"

function populate_postgres() {
  echo "~~~~~~"
  unzip -o /tmp/sample_data.zip -d /tmp
  echo "$(date) POPULATING POSTGRES"

  psql "postgresql://$CBDPGUSER:$CBDPGPASSWORD@$CBDPGHOST:$CBDPGPORT/$CBDPGDATABASE?sslmode=prefer" -f data_setup.sql --quiet --echo-errors

  echo "Importing sample data"
  psql "postgresql://$CBDPGUSER:$CBDPGPASSWORD@$CBDPGHOST:$CBDPGPORT/$CBDPGDATABASE?sslmode=prefer" --echo-errors -c "\COPY device FROM '/tmp/device_short.csv' DELIMITER ',';"
  psql "postgresql://$CBDPGUSER:$CBDPGPASSWORD@$CBDPGHOST:$CBDPGPORT/$CBDPGDATABASE?sslmode=prefer" --echo-errors -c "\COPY device_group FROM '/tmp/device_group_short.csv' DELIMITER ',';"
  psql "postgresql://$CBDPGUSER:$CBDPGPASSWORD@$CBDPGHOST:$CBDPGPORT/$CBDPGDATABASE?sslmode=prefer" --echo-errors -c "\COPY organization FROM '/tmp/organization_short.csv' DELIMITER ',';"
  psql "postgresql://$CBDPGUSER:$CBDPGPASSWORD@$CBDPGHOST:$CBDPGPORT/$CBDPGDATABASE?sslmode=prefer" --echo-errors -c "Update device set org_key = '7ZP4H2LG' where device_id = 6424575;"
  psql "postgresql://$CBDPGUSER:$CBDPGPASSWORD@$CBDPGHOST:$CBDPGPORT/$CBDPGDATABASE?sslmode=prefer" --echo-errors -c "Update device_group set org_id=1180 where device_group_id = 14148669;"
  psql "postgresql://$CBDPGUSER:$CBDPGPASSWORD@$CBDPGHOST:$CBDPGPORT/$CBDPGDATABASE?sslmode=prefer" --echo-errors -c "insert into device_group_device (device_group_id, device_id) values (13632612, 1013), (13632614, 1018), (13632613, 1015), (13632615, 1014), (12643171, 34466), (14148669, 1020);"
  psql "postgresql://$CBDPGUSER:$CBDPGPASSWORD@$CBDPGHOST:$CBDPGPORT/$CBDPGDATABASE?sslmode=prefer" --echo-errors -c "insert into org_domain (org_id, domain_name, is_default) values (4040740, 'junk.com', false), (3697474, 'junk2.com', false), (1180, 'junk3.com', false);"

  echo "Done Importing sample data"

  if [[ $? -eq 0 ]]; then
    echo -e "\n$(date) DONE POPULATING POSTGRES"
  else
    echo -e "\n$(date) ERROR POPULATING POSTGRES"
    exit 1
  fi
}

echo "$(date) POPULATING TEST DATA"

populate_elasticsearch
populate_postgres

echo "$(date) DONE POPULATING TEST DATA"
